==> breeze_website_builder_6.5.02.tar.gz: manage/plugins/lang/gallery/lt.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Tvarkyti lightbox gallary parametrai");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "tvarkyti galerija");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Visu dydžiu Plotis");
define('MANAGE_GALLERY_FULL_HEIGHT', "Visu dydžiu Aukštis");
define('MANAGE_GALLERY_THUMB_WIDTH', "Thumbnail image Plotis");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Thumbnail image Ūgis");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Išsaugoti Thumb Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "Rodyti Titulai");
define('MANAGE_GALLERY_DISABLE_SORT', "Išjungti Rūšiuoti");
define('MANAGE_GALLERY_DELETE_IMAGE', "Ištrinti Image");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Išsaugoti Rūšiavimo Tvarką");
define('MANAGE_GALLERY_PUBLISH_MSG', "Spustelėkite &quot;Atnaujinti&quot; skelbti <br /> Jūsų įkelta vaizdų.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Visos nuotraukos buvo pakeistas ir buvo išgelbėtas nustatymai.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Nebuvo dydį vaizdus ar taupymo nustatymus įvyko klaida.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Jūsų vaizdai (-ų) buvo įkeltas.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Įkeliant savo vaizdai (-ų) įvyko klaida.");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Failas bandote įkelti nėra vaizdo.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Failas bandote įkelti yra per didelis.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Pavadinimas buvo išsaugotas.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Ar tikrai norite ištrinti nuotrauką");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Vaizdas buvo ištrintas.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Nebuvo ištrinti vaizdą įvyko klaida.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Taupymo parametrus ir dydį vaizdus, ​​prašome palaukti ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Siuntimas, prašome palaukti ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Rūšiavimo tvarką nebuvo išsaugotas. Ar norite išsaugoti rūšiavimo tvarką?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Vaizdas rūšiavimo tvarka buvo išsaugotas.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Išsaugant vaizdo rūšiuoti įvyko klaida.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/lt.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Tvarkyti lightbox gallary parametrai");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "tvarkyti galerija");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Visu dydžiu Plotis");
define('MANAGE_GALLERY_FULL_HEIGHT', "Visu dydžiu Aukštis");
define('MANAGE_GALLERY_THUMB_WIDTH', "Thumbnail image Plotis");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Thumbnail image Ūgis");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Išsaugoti Thumb Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "Rodyti Titulai");
define('MANAGE_GALLERY_DISABLE_SORT', "Išjungti Rūšiuoti");
define('MANAGE_GALLERY_DELETE_IMAGE', "Ištrinti Image");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Išsaugoti Rūšiavimo Tvarką");
define('MANAGE_GALLERY_PUBLISH_MSG', "Spustelėkite &quot;Atnaujinti&quot; skelbti <br /> Jūsų įkelta vaizdų.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Visos nuotraukos buvo pakeistas ir buvo išgelbėtas nustatymai.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Nebuvo dydį vaizdus ar taupymo nustatymus įvyko klaida.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Jūsų vaizdai (-ų) buvo įkeltas.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Įkeliant savo vaizdai (-ų) įvyko klaida.");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Failas bandote įkelti nėra vaizdo.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Failas bandote įkelti yra per didelis.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Pavadinimas buvo išsaugotas.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Ar tikrai norite ištrinti nuotrauką");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Vaizdas buvo ištrintas.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Nebuvo ištrinti vaizdą įvyko klaida.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Taupymo parametrus ir dydį vaizdus, ​​prašome palaukti ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Siuntimas, prašome palaukti ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Rūšiavimo tvarką nebuvo išsaugotas. Ar norite išsaugoti rūšiavimo tvarką?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Vaizdas rūšiavimo tvarka buvo išsaugotas.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Išsaugant vaizdo rūšiuoti įvyko klaida.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Failas, kurį bandote įkelti, yra didesnis nei „upload_max_filesize“ arba „post_max_size“ PHP nustatymai. Kreipkitės į sistemos administratorių, kad padidintumėte šias ribas.");
?>
